@@ -11,7 +11,7 @@ Usage:
   cloudmesh-installer info [BUNDLE] [--verbose]
   cloudmesh-installer clean --dir=DIR [--force]
   cloudmesh-installer clean --venv=ENV [--force]
-  cloudmesh-installer new VENV [BUNDLES...]
+  cloudmesh-installer new VENV [BUNDLES...] [--python=PYTHON]
   cloudmesh-installer release [REPOS...] [--benchmark]
 
 
@@ -128,276 +128,13 @@ from cloudmesh.common.StopWatch import StopWatch
 from cloudmesh.common.console import Console
 from cloudmesh.common.util import banner
 
+from cloudmesh_installer.install.bundle import *
+
 from cloudmesh_installer.install.__version__ import version as insatller_version
 
 debug = False
 benchmark = False
 
-# 'cloudmesh-azure',
-# 'cloudmesh-aws'
-
-cms = [
-    'cloudmesh-common',
-    'cloudmesh-cmd5',
-    'cloudmesh-sys',
-    'cloudmesh-configuration',
-    'cloudmesh-test',
-    'cloudmesh-gui',
-    'cloudmesh-abstract'
-]
-
-cmd5 = [
-    'cloudmesh-common',
-    'cloudmesh-cmd5',
-    'cloudmesh-sys',
-]
-
-cloud = cms + [
-    'cloudmesh-cloud',
-    'cloudmesh-inventory',
-    'cloudmesh-openstack',
-]
-
-repos = dict({
-
-    'cms': cms,
-
-    'cmd5': cmd5,
-
-    'sys': cms,
-
-    'common': {
-        'cloudmesh-common'
-    },
-
-    'manual': cms + cloud + [
-        'cloudmesh-azure',
-        'cloudmesh-aws',
-        'cloudmesh-openstack',
-        'cloudmesh-google',
-        'cloudmesh-oracle',
-        'cloudmesh-storage',
-        'cloudmesh-cmsd',
-        'cloudmesh-multipass',
-        'cloudmesh-manual'
-
-    ],
-
-    'cloud': cloud,
-
-    'gui': cloud + [
-        'cloudmesh-gui'
-    ],
-
-    'encrypt': [
-        'cloudmesh-encrypt'
-    ],
-
-    'libcloud': [
-        'cloudmesh-libcloud'
-    ],
-
-    'inventory': cms + [
-        'cloudmesh-inventory'
-    ],
-
-    'test': cms + [
-        'cloudmesh-test'
-    ],
-
-    'volume': cms + cloud + [
-        'cloudmesh-gui',
-        'cloudmesh-volume'
-    ],
-
-    'multipass': cms + cloud + [
-        'cloudmesh-multipass'
-    ],
-
-    'cmsd': cms + [
-        'cloudmesh-gui',
-        'cloudmesh-cmsd'
-    ],
-
-    'cmsdcontainer': [
-        'cloudmesh-common',
-        'cloudmesh-cmd5',
-        'cloudmesh-sys',
-        'cloudmesh-configuration',
-        'cloudmesh-inventory',
-        'cloudmesh-cmsd',
-        'cloudmesh-azure',
-        'cloudmesh-aws',
-        'cloudmesh-openstack',
-        'cloudmesh-google',
-        'cloudmesh-oracle',
-        'cloudmesh-multipass'
-#        'cloudmesh-storage',
-    ],
-
-    'docker': ['cloudmesh-cmsd'],
-
-    'iu': cloud + [
-        'cloudmesh-iu'
-    ],
-
-    'batch': cloud + [
-        'cloudmesh-batch'
-    ],
-
-    'storage': cloud + [
-        'cloudmesh-storage',
-        'cloudmesh-box'
-    ],
-
-    'oracle': cloud + [
-        'cloudmesh-storage',
-        'cloudmesh-oracle'
-    ],
-
-    'aws': cloud + [
-        'cloudmesh-aws'
-    ],
-
-    'azure': cloud + [
-        'cloudmesh-azure'
-    ],
-
-    'openstack': cloud + [
-        'cloudmesh-openstack'
-    ],
-
-    'google': cloud + [
-        'cloudmesh-storage',
-        'cloudmesh-google'
-    ],
-
-    'compute': cloud + [
-        'cloudmesh-aws',
-        'cloudmesh-azure',
-        'cloudmesh-apoenstack',
-        'cloudmesh-google'
-    ],
-
-    'provider': cloud + [
-        'cloudmesh-aws',
-        'cloudmesh-azure',
-        'cloudmesh-openstack',
-        'cloudmesh-google'
-    ],
-    'frugal': cloud + [
-        'cloudmesh-frugal'
-    ],
-
-    'analytics': cms + [
-        'cloudmesh-cloud',
-        'cloudmesh-analytics',
-        'cloudmesh-openapi',
-    ],
-
-    'openapi': cms + [
-        'cloudmesh-cloud',
-        'cloudmesh-openapi',
-    ],
-
-    'source': cloud + [
-        'cloudmesh-analytics',
-        'cloudmesh-aws',
-        'cloudmesh-azure',
-        'cloudmesh-bar',
-        'cloudmesh-batch',
-        'cloudmesh-box',
-        'cloudmesh-cmsd',
-        'cloudmesh-comet',
-        'cloudmesh-conda',
-        'cloudmesh-docker',
-        'cloudmesh-emr',
-        'cloudmesh-flow',
-        'cloudmesh-flow2',
-        'cloudmesh-git',
-        'cloudmesh-google',
-        'cloudmesh-gui',
-        'cloudmesh-iu',
-        'cloudmesh-nist',
-        'cloudmesh-nn',
-        'cloudmesh-notebooks',
-        'cloudmesh-openapi',
-        'cloudmesh-oracle',
-        'cloudmesh-redshift',
-        'cloudmesh-stopwatch',
-        'cloudmesh-storage',
-        'cloudmesh-workflow',
-        'cloudmesh-storagelifecycle',
-        'cloudmesh-oracle',
-        'cloudmesh-frugal',
-        'cloudmesh-analytics',
-        'cloudmesh-volume'
-    ],
-
-    'web': [
-        'about',
-        'get',
-        'cloudmesh-github.io',
-        'cloudmesh-manual'
-    ],
-
-    'community': [
-        'cloudmesh-community.github.io'
-    ],
-
-    'flow': cloud + [
-        'cloudmesh-flow',
-    ],
-
-    'emr': cloud + [
-        'cloudmesh-emr',
-    ],
-
-    'conda': [
-        'cloudmesh-conda'
-    ],
-
-    'fa19-516': hostlist.expand_hostlist("fa19-516-[140-172,174]"),
-
-    'fa19-523': hostlist.expand_hostlist("fa19-523-[180-196,198-212]"),
-
-    'sp20': hostlist.expand_hostlist(
-        "fa19-516-[153,141,148,158,172,169,174,168]") \
-        + hostlist.expand_hostlist("sp20-516-[220,222-224,227,229-241,243,245-248,250-255]"),
-
-    'sp19':
-        [
-            'hid-sample',
-            'hid-sp18-407',
-            'hid-sp18-512',
-            'hid-sp18-519',
-            'hid-sp18-520',
-            'hid-sp18-522',
-            'hid-sp18-523',
-            'hid-sp18-602',
-            'hid-sp18-701',
-            'hid-sp18-704',
-            'hid-sp18-709',
-            'hid-sp18-710',
-            'sp19-616-111',
-            'sp19-616-112'
-        ] \
-        + hostlist.expand_hostlist("sp19-516-[22,26,29,121-125,127-139]") \
-        + hostlist.expand_hostlist("sp19-222-[89-94,96-102]"),
-
-    'bookmanager':
-        [
-            'bookmanager'
-            'bookmanager-service'
-        ],
-
-    'book':
-        [
-            'book'
-        ]
-})
-
-
 
 def run(command, verbose=True):
     global benchmark
@@ -1009,6 +746,7 @@ def main():
 
     elif arguments["new"]:
 
+        python= arguments["--python"] or "python3.8"
         venv = arguments["VENV"] or os.path.basename(os.environ("VIRTUAL_ENV")) or "~/ENV3"
 
         if os.path.basename(venv).startswith("ENV") and yn_question(
@@ -1016,7 +754,7 @@ def main():
 
             script = textwrap.dedent(f"""
             rm -rf {venv}
-            python3.8 -m venv {venv}
+            {python} -m venv {venv}
             source {venv}/bin/activate
             pip install pip -U
             which python
